Index: cprs/branches/tmg-cprs/CPRS-Chart/Accessibility_TLB.pas
===================================================================
--- cprs/branches/tmg-cprs/CPRS-Chart/Accessibility_TLB.pas	(revision 660)
+++ cprs/branches/tmg-cprs/CPRS-Chart/Accessibility_TLB.pas	(revision 667)
@@ -13,5 +13,5 @@
 
 // PASTLWTR : 1.2
-// File generated on 12/28/2009 9:26:13 PM from Type Library described below.
+// File generated on 1/12/2010 1:11:24 PM from Type Library described below.
 
 // ************************************************************************  //
Index: cprs/branches/tmg-cprs/CPRS-Chart/CPRSChart.dsk
===================================================================
--- cprs/branches/tmg-cprs/CPRS-Chart/CPRSChart.dsk	(revision 660)
+++ cprs/branches/tmg-cprs/CPRS-Chart/CPRSChart.dsk	(revision 667)
@@ -1,31 +1,93 @@
 [Closed Files]
-File_0=SourceModule,'c:\program files\borland\delphi7\source\vcl\ComCtrls.pas',0,1,8808,1,8828,0,0
-File_1=SourceModule,'c:\program files\borland\delphi7\source\rtl\Sys\variants.pas',0,1,740,1,747,0,0
-File_2=SourceModule,'P:\vista\tmg-cprs\CPRS-Chart\TMG_Extra\HTMLEdit\EmbeddedED\EmbeddedED.pas',0,1,3123,1,3130,0,0
+File_0=SourceModule,'c:\program files\borland\delphi7\source\rtl\Sys\variants.pas',0,1,740,1,747,0,0
+File_1=SourceModule,'P:\vista\tmg-cprs\CPRS-Chart\TMG_Extra\HTMLEdit\EmbeddedED\EmbeddedED.pas',0,1,3123,1,3130,0,0
 
 [Modules]
-Module0=P:\vista\tmg-cprs\CPRS-Chart\TMG_Extra\fWebTab.pas
-Module1=P:\vista\tmg-cprs\CPRS-Chart\fFrame.pas
-Module2=P:\vista\tmg-cprs\CPRS-Chart\Encounter\fEncounterFrame.pas
-Module3=P:\vista\tmg-cprs\CPRS-Chart\fNotes.pas
-Module4=P:\vista\tmg-cprs\CPRS-Chart\fPtSel.pas
-Module5=P:\vista\tmg-cprs\CPRS-Chart\Options\fOptionsNotes.pas
-Module6=C:\PROGRA~1\VISTA\BDK32\Source\wsockc.pas
-Module7=c:\program files\borland\delphi7\source\rtl\Sys\sysutils.pas
-Module8=c:\program files\borland\delphi7\source\vcl\Menus.pas
-Module9=c:\program files\borland\delphi7\source\rtl\Sys\system.pas
-Module10=P:\Vista\tmg-cprs\dklang-package-3.01\DKLang.pas
-Module11=P:\vista\tmg-cprs\CPRS-Chart\fDrawers.pas
-Module12=c:\program files\borland\delphi7\source\rtl\common\classes.pas
-Module13=P:\vista\tmg-cprs\CPRS-Chart\fReports.pas
-Module14=c:\program files\borland\delphi7\source\vcl\Controls.pas
-Module15=P:\vista\tmg-cprs\CPRS-Chart\Templates\uTemplateFields.pas
-Module16=P:\vista\tmg-cprs\CPRS-Chart\Templates\fTemplateDialog.pas
-Module17=P:\vista\tmg-cprs\CPRS-Chart\TMG_Extra\HTMLEdit\TMGHTML2.pas
-Module18=P:\vista\tmg-cprs\CPRS-Chart\CPRSChart.dpr
-Count=19
+Module0=P:\vista\tmg-cprs\CPRS-Chart\fFrame.pas
+Module1=P:\vista\tmg-cprs\CPRS-Chart\Options\fOptionsOther.pas
+Module2=P:\vista\tmg-cprs\CPRS-Chart\Options\fOptionsNotes.pas
+Module3=P:\vista\tmg-cprs\CPRS-Chart\Encounter\fEncounterFrame.pas
+Module4=c:\program files\borland\delphi7\source\rtl\Sys\sysutils.pas
+Module5=c:\program files\borland\delphi7\source\vcl\Menus.pas
+Module6=c:\program files\borland\delphi7\source\rtl\Sys\system.pas
+Module7=P:\Vista\tmg-cprs\dklang-package-3.01\DKLang.pas
+Module8=P:\vista\tmg-cprs\CPRS-Chart\fDrawers.pas
+Module9=c:\program files\borland\delphi7\source\rtl\common\classes.pas
+Module10=P:\vista\tmg-cprs\CPRS-Chart\fNotes.pas
+Module11=P:\vista\tmg-cprs\CPRS-Chart\fReports.pas
+Module12=P:\vista\tmg-cprs\CPRS-Chart\TMG_Extra\fWebTab.pas
+Module13=c:\program files\borland\delphi7\source\vcl\ComCtrls.pas
+Module14=c:\program files\borland\delphi7\source\vcl\Forms.pas
+Module15=c:\program files\borland\delphi7\source\vcl\Graphics.pas
+Module16=P:\vista\tmg-cprs\CPRS-Chart\fPtSel.pas
+Module17=c:\program files\borland\delphi7\source\vcl\Controls.pas
+Module18=P:\vista\tmg-cprs\CPRS-Chart\Templates\uTemplateFields.pas
+Module19=P:\vista\tmg-cprs\CPRS-Chart\Templates\fTemplateDialog.pas
+Module20=P:\vista\tmg-cprs\CPRS-Chart\TMG_Extra\HTMLEdit\TMGHTML2.pas
+Module21=P:\vista\tmg-cprs\CPRS-Chart\CPRSChart.dpr
+Count=22
 EditWindowCount=1
 TypeLibWindowCount=1
 
+[P:\vista\tmg-cprs\CPRS-Chart\fFrame.pas]
+ModuleType=SourceModule
+FormState=1
+FormOnTop=1
+
+[P:\vista\tmg-cprs\CPRS-Chart\Options\fOptionsOther.pas]
+ModuleType=SourceModule
+FormState=1
+FormOnTop=0
+
+[P:\vista\tmg-cprs\CPRS-Chart\Options\fOptionsNotes.pas]
+ModuleType=SourceModule
+FormState=0
+FormOnTop=0
+
+[P:\vista\tmg-cprs\CPRS-Chart\Encounter\fEncounterFrame.pas]
+ModuleType=SourceModule
+FormState=1
+FormOnTop=0
+
+[c:\program files\borland\delphi7\source\rtl\Sys\sysutils.pas]
+ModuleType=SourceModule
+FormState=0
+FormOnTop=0
+
+[c:\program files\borland\delphi7\source\vcl\Menus.pas]
+ModuleType=SourceModule
+FormState=0
+FormOnTop=0
+
+[c:\program files\borland\delphi7\source\rtl\Sys\system.pas]
+ModuleType=SourceModule
+FormState=0
+FormOnTop=0
+
+[P:\Vista\tmg-cprs\dklang-package-3.01\DKLang.pas]
+ModuleType=SourceModule
+FormState=0
+FormOnTop=0
+
+[P:\vista\tmg-cprs\CPRS-Chart\fDrawers.pas]
+ModuleType=SourceModule
+FormState=0
+FormOnTop=0
+
+[c:\program files\borland\delphi7\source\rtl\common\classes.pas]
+ModuleType=SourceModule
+FormState=0
+FormOnTop=0
+
+[P:\vista\tmg-cprs\CPRS-Chart\fNotes.pas]
+ModuleType=SourceModule
+FormState=0
+FormOnTop=0
+
+[P:\vista\tmg-cprs\CPRS-Chart\fReports.pas]
+ModuleType=SourceModule
+FormState=0
+FormOnTop=0
+
 [P:\vista\tmg-cprs\CPRS-Chart\TMG_Extra\fWebTab.pas]
 ModuleType=SourceModule
@@ -33,15 +95,15 @@
 FormOnTop=0
 
-[P:\vista\tmg-cprs\CPRS-Chart\fFrame.pas]
-ModuleType=SourceModule
-FormState=0
-FormOnTop=0
-
-[P:\vista\tmg-cprs\CPRS-Chart\Encounter\fEncounterFrame.pas]
-ModuleType=SourceModule
-FormState=0
-FormOnTop=1
-
-[P:\vista\tmg-cprs\CPRS-Chart\fNotes.pas]
+[c:\program files\borland\delphi7\source\vcl\ComCtrls.pas]
+ModuleType=SourceModule
+FormState=0
+FormOnTop=0
+
+[c:\program files\borland\delphi7\source\vcl\Forms.pas]
+ModuleType=SourceModule
+FormState=0
+FormOnTop=0
+
+[c:\program files\borland\delphi7\source\vcl\Graphics.pas]
 ModuleType=SourceModule
 FormState=0
@@ -50,49 +112,4 @@
 [P:\vista\tmg-cprs\CPRS-Chart\fPtSel.pas]
 ModuleType=SourceModule
-FormState=1
-FormOnTop=0
-
-[P:\vista\tmg-cprs\CPRS-Chart\Options\fOptionsNotes.pas]
-ModuleType=SourceModule
-FormState=1
-FormOnTop=0
-
-[C:\PROGRA~1\VISTA\BDK32\Source\wsockc.pas]
-ModuleType=SourceModule
-FormState=0
-FormOnTop=0
-
-[c:\program files\borland\delphi7\source\rtl\Sys\sysutils.pas]
-ModuleType=SourceModule
-FormState=0
-FormOnTop=0
-
-[c:\program files\borland\delphi7\source\vcl\Menus.pas]
-ModuleType=SourceModule
-FormState=0
-FormOnTop=0
-
-[c:\program files\borland\delphi7\source\rtl\Sys\system.pas]
-ModuleType=SourceModule
-FormState=0
-FormOnTop=0
-
-[P:\Vista\tmg-cprs\dklang-package-3.01\DKLang.pas]
-ModuleType=SourceModule
-FormState=0
-FormOnTop=0
-
-[P:\vista\tmg-cprs\CPRS-Chart\fDrawers.pas]
-ModuleType=SourceModule
-FormState=0
-FormOnTop=0
-
-[c:\program files\borland\delphi7\source\rtl\common\classes.pas]
-ModuleType=SourceModule
-FormState=0
-FormOnTop=0
-
-[P:\vista\tmg-cprs\CPRS-Chart\fReports.pas]
-ModuleType=SourceModule
 FormState=0
 FormOnTop=0
@@ -131,4 +148,8 @@
 FormOnTop=0
 
+[P:\vista\tmg-cprs\CPRS-Chart\dShared.pas]
+FormState=0
+FormOnTop=0
+
 [P:\vista\tmg-cprs\CPRS-Chart\fHSplit.pas]
 FormState=0
@@ -139,11 +160,7 @@
 FormOnTop=0
 
-[P:\vista\tmg-cprs\CPRS-Chart\dShared.pas]
-FormState=0
-FormOnTop=0
-
 [EditWindow0]
-ViewCount=19
-CurrentView=9
+ViewCount=22
+CurrentView=8
 View0=0
 View1=1
@@ -165,30 +182,35 @@
 View17=17
 View18=18
+View19=19
+View20=20
+View21=21
 CodeExplorer=CodeExplorer@EditWindow0
 MessageView=MessageView@EditWindow0
 Create=1
 Visible=1
-State=0
-Left=66
-Top=138
-Width=902
-Height=607
-MaxLeft=-1
-MaxTop=-1
-ClientWidth=894
-ClientHeight=573
-LeftPanelSize=140
+State=2
+Left=221
+Top=132
+Width=803
+Height=591
+MaxLeft=-4
+MaxTop=108
+MaxWidth=1032
+MaxHeight=664
+ClientWidth=1024
+ClientHeight=630
+LeftPanelSize=0
 LeftPanelClients=CodeExplorer@EditWindow0
-LeftPanelData=000004000000000000000000000000000000000000000000000100000000000000000C000000436F64654578706C6F726572FFFFFFFF
+LeftPanelData=00000400010000000C000000436F64654578706C6F726572000000000000000000000000000000000001000000000000000000000000FFFFFFFF
 RightPanelSize=0
-BottomPanelSize=226
-BottomPanelClients=MessageView@EditWindow0,WatchWindow
-BottomPanelData=0000040000000000E200000000000000017E030000000000000100000000860000000B0000004D657373616765566965770100000000E20000000B000000576174636857696E646F77FFFFFFFF
+BottomPanelSize=245
+BottomPanelClients=DockSite1,MessageView@EditWindow0
+BottomPanelData=00000400010000000B0000004D65737361676556696577F50000000000000001000400000000000001000000002A000000000000000100000002F50000000000000002000000000004000009000000446F636B53697465310200000000000400000B0000004D65737361676556696577FFFFFFFF
 
 [View0]
 Module=P:\vista\tmg-cprs\CPRS-Chart\CPRSChart.dpr
 CursorX=1
-CursorY=1
-TopLine=1
+CursorY=366
+TopLine=357
 LeftCol=1
 
@@ -218,5 +240,5 @@
 CursorX=1
 CursorY=347
-TopLine=339
+TopLine=324
 LeftCol=1
 
@@ -224,6 +246,6 @@
 Module=c:\program files\borland\delphi7\source\vcl\Controls.pas
 CursorX=1
-CursorY=4706
-TopLine=4698
+CursorY=6245
+TopLine=6231
 LeftCol=1
 
@@ -237,17 +259,45 @@
 [View7]
 Module=P:\vista\tmg-cprs\CPRS-Chart\Encounter\fEncounterFrame.pas
-CursorX=30
-CursorY=432
-TopLine=424
+CursorX=42
+CursorY=369
+TopLine=361
 LeftCol=1
 
 [View8]
 Module=P:\vista\tmg-cprs\CPRS-Chart\fFrame.pas
-CursorX=28
-CursorY=1112
-TopLine=1106
+CursorX=1
+CursorY=1511
+TopLine=1502
 LeftCol=1
 
 [View9]
+Module=P:\vista\tmg-cprs\CPRS-Chart\Options\fOptionsOther.pas
+CursorX=60
+CursorY=354
+TopLine=347
+LeftCol=1
+
+[View10]
+Module=c:\program files\borland\delphi7\source\vcl\Graphics.pas
+CursorX=1
+CursorY=2325
+TopLine=2317
+LeftCol=1
+
+[View11]
+Module=c:\program files\borland\delphi7\source\vcl\Forms.pas
+CursorX=1
+CursorY=2974
+TopLine=2961
+LeftCol=1
+
+[View12]
+Module=c:\program files\borland\delphi7\source\vcl\ComCtrls.pas
+CursorX=1
+CursorY=4197
+TopLine=4188
+LeftCol=1
+
+[View13]
 Module=P:\vista\tmg-cprs\CPRS-Chart\TMG_Extra\fWebTab.pas
 CursorX=10
@@ -256,5 +306,5 @@
 LeftCol=1
 
-[View10]
+[View14]
 Module=P:\vista\tmg-cprs\CPRS-Chart\fReports.pas
 CursorX=33
@@ -263,5 +313,5 @@
 LeftCol=1
 
-[View11]
+[View15]
 Module=P:\vista\tmg-cprs\CPRS-Chart\fNotes.pas
 CursorX=22
@@ -270,12 +320,12 @@
 LeftCol=1
 
-[View12]
+[View16]
 Module=c:\program files\borland\delphi7\source\rtl\common\classes.pas
 CursorX=1
-CursorY=4214
-TopLine=4202
-LeftCol=1
-
-[View13]
+CursorY=3986
+TopLine=3974
+LeftCol=1
+
+[View17]
 Module=P:\vista\tmg-cprs\CPRS-Chart\fDrawers.pas
 CursorX=1
@@ -284,5 +334,5 @@
 LeftCol=1
 
-[View14]
+[View18]
 Module=P:\Vista\tmg-cprs\dklang-package-3.01\DKLang.pas
 CursorX=1
@@ -291,12 +341,12 @@
 LeftCol=1
 
-[View15]
+[View19]
 Module=c:\program files\borland\delphi7\source\rtl\Sys\system.pas
 CursorX=1
-CursorY=10701
-TopLine=10693
-LeftCol=1
-
-[View16]
+CursorY=11719
+TopLine=11704
+LeftCol=1
+
+[View20]
 Module=c:\program files\borland\delphi7\source\vcl\Menus.pas
 CursorX=1
@@ -305,16 +355,9 @@
 LeftCol=1
 
-[View17]
+[View21]
 Module=c:\program files\borland\delphi7\source\rtl\Sys\sysutils.pas
 CursorX=1
-CursorY=16177
-TopLine=16169
-LeftCol=1
-
-[View18]
-Module=C:\PROGRA~1\VISTA\BDK32\Source\wsockc.pas
-CursorX=1
-CursorY=1479
-TopLine=1468
+CursorY=4343
+TopLine=4331
 LeftCol=1
 
@@ -343,18 +386,18 @@
 Visible=1
 State=0
-Left=12
-Top=134
-Width=882
-Height=92
-MaxLeft=-1
-MaxTop=-1
-ClientWidth=882
-ClientHeight=92
-TBDockHeight=92
+Left=0
+Top=0
+Width=1004
+Height=216
+MaxLeft=-1
+MaxTop=-1
+ClientWidth=1004
+ClientHeight=216
+TBDockHeight=264
 LRDockWidth=421
 Dockable=1
 
 [Breakpoints]
-Count=10
+Count=12
 Breakpoint0='P:\vista\tmg-cprs\CPRS-Chart\rCover.pas',315,'',0,1,'',1,0,0,'',1,'','',''
 Breakpoint1='P:\vista\tmg-cprs\TMG_Extra\HTMLEdit\EmbeddedED\EmbeddedED.pas',1516,'',0,1,'',1,0,0,'',1,'','',''
@@ -367,4 +410,6 @@
 Breakpoint8='P:\vista\tmg-cprs\CPRS-Chart\Options\fOptionsNotes.pas',293,'',0,1,'',1,0,0,'',1,'','',''
 Breakpoint9='P:\vista\tmg-cprs\CPRS-Chart\fFrame.pas',3692,'',0,1,'',1,0,0,'',1,'','',''
+Breakpoint10='P:\vista\tmg-cprs\CPRS-Chart\fFrame.pas',1059,'',0,1,'',1,0,0,'',1,'','',''
+Breakpoint11='P:\vista\tmg-cprs\CPRS-Chart\fFrame.pas',1076,'',0,1,'',1,0,0,'',1,'','',''
 
 [AddressBreakpoints]
@@ -374,14 +419,12 @@
 Create=1
 Visible=1
-State=2
-Left=170
-Top=3
-Width=854
+State=0
+Left=0
+Top=0
+Width=1024
 Height=112
 MaxLeft=-1
 MaxTop=-1
-MaxWidth=1032
-MaxHeight=112
-ClientWidth=1024
+ClientWidth=1016
 ClientHeight=78
 
@@ -390,14 +433,14 @@
 Visible=0
 State=0
-Left=198
-Top=142
-Width=689
-Height=561
-MaxLeft=-1
-MaxTop=-1
-ClientWidth=681
-ClientHeight=535
+Left=31
+Top=128
+Width=454
+Height=568
+MaxLeft=-1
+MaxTop=-1
+ClientWidth=446
+ClientHeight=542
 TBDockHeight=408
-LRDockWidth=623
+LRDockWidth=140
 Dockable=1
 
@@ -422,13 +465,13 @@
 Visible=0
 State=0
-Left=0
-Top=39
-Width=800
-Height=561
-MaxLeft=-1
-MaxTop=-1
-ClientWidth=792
-ClientHeight=527
-DumpPane=87
+Left=78
+Top=201
+Width=731
+Height=488
+MaxLeft=-1
+MaxTop=-1
+ClientWidth=723
+ClientHeight=454
+DumpPane=79
 DisassemblyPane=187
 RegisterPane=231
@@ -439,6 +482,6 @@
 Visible=0
 State=0
-Left=53
-Top=123
+Left=98
+Top=122
 Width=156
 Height=84
@@ -454,17 +497,17 @@
 Left=0
 Top=0
-Width=326
-Height=427
-MaxLeft=-1
-MaxTop=-1
-ClientWidth=326
-ClientHeight=427
-TBDockHeight=527
-LRDockWidth=250
-Dockable=1
-SplitPos=128
+Width=262
+Height=540
+MaxLeft=-1
+MaxTop=-1
+ClientWidth=262
+ClientHeight=540
+TBDockHeight=492
+LRDockWidth=190
+Dockable=1
+SplitPos=114
 ArrangeBy=Name
-SelectedItem=Caption
-ExpandedItems=Anchors,Options
+SelectedItem=Action
+ExpandedItems=CalColors,EdgeBorders,Options
 HiddenCategories=Legacy
 
@@ -473,6 +516,6 @@
 Visible=0
 State=0
-Left=-744
-Top=207
+Left=20
+Top=265
 Width=737
 Height=350
@@ -484,5 +527,5 @@
 LRDockWidth=737
 Dockable=1
-Column0Width=178
+Column0Width=100
 Column1Width=75
 Column2Width=200
@@ -495,14 +538,14 @@
 Visible=0
 State=0
-Left=363
-Top=83
-Width=420
-Height=412
-MaxLeft=-1
-MaxTop=-1
-ClientWidth=412
-ClientHeight=386
-TBDockHeight=355
-LRDockWidth=233
+Left=55
+Top=390
+Width=443
+Height=350
+MaxLeft=-1
+MaxTop=-1
+ClientWidth=435
+ClientHeight=324
+TBDockHeight=411
+LRDockWidth=155
 Dockable=1
 
@@ -533,26 +576,26 @@
 Left=0
 Top=0
-Width=326
-Height=427
-MaxLeft=-1
-MaxTop=-1
-ClientWidth=326
-ClientHeight=427
-TBDockHeight=527
-LRDockWidth=250
+Width=262
+Height=540
+MaxLeft=-1
+MaxTop=-1
+ClientWidth=262
+ClientHeight=540
+TBDockHeight=175
+LRDockWidth=108
 Dockable=1
 
 [DebugLogView]
 Create=1
-Visible=0
-State=0
-Left=431
-Top=254
-Width=417
-Height=291
-MaxLeft=-1
-MaxTop=-1
-ClientWidth=409
-ClientHeight=265
+Visible=1
+State=0
+Left=0
+Top=0
+Width=1004
+Height=216
+MaxLeft=-1
+MaxTop=-1
+ClientWidth=1004
+ClientHeight=216
 TBDockHeight=291
 LRDockWidth=417
@@ -603,6 +646,6 @@
 Visible=0
 State=0
-Left=310
-Top=284
+Left=307
+Top=281
 Width=457
 Height=250
@@ -653,14 +696,14 @@
 [CodeExplorer@EditWindow0]
 Create=1
-Visible=1
+Visible=0
 State=0
 Left=0
 Top=12
 Width=140
-Height=332
+Height=383
 MaxLeft=-1
 MaxTop=-1
 ClientWidth=140
-ClientHeight=332
+ClientHeight=383
 TBDockHeight=305
 LRDockWidth=140
@@ -669,20 +712,20 @@
 [MessageView@EditWindow0]
 Create=1
-Visible=1
-State=0
-Left=12
+Visible=0
+State=0
+Left=376
 Top=0
-Width=882
-Height=130
-MaxLeft=-1
-MaxTop=-1
-ClientWidth=882
-ClientHeight=130
-TBDockHeight=130
+Width=648
+Height=245
+MaxLeft=-1
+MaxTop=-1
+ClientWidth=648
+ClientHeight=245
+TBDockHeight=245
 LRDockWidth=443
 Dockable=1
 
 [DockHosts]
-DockHostCount=1
+DockHostCount=2
 
 [DockSite0]
@@ -691,14 +734,14 @@
 Visible=1
 State=0
-Left=12
-Top=118
-Width=342
-Height=482
-MaxLeft=-1
-MaxTop=-1
-ClientWidth=334
-ClientHeight=456
-TBDockHeight=539
-LRDockWidth=258
+Left=2
+Top=121
+Width=278
+Height=595
+MaxLeft=-1
+MaxTop=-1
+ClientWidth=270
+ClientHeight=569
+TBDockHeight=552
+LRDockWidth=272
 Dockable=1
 TabPosition=0
@@ -706,2 +749,22 @@
 TabDockClients=PropertyInspector,ObjectTree
 
+[DockSite1]
+DockSiteType=1
+Create=1
+Visible=1
+State=0
+Left=12
+Top=0
+Width=1012
+Height=245
+MaxLeft=-1
+MaxTop=-1
+ClientWidth=1012
+ClientHeight=245
+TBDockHeight=245
+LRDockWidth=283
+Dockable=1
+TabPosition=0
+ActiveTab=Watch List
+TabDockClients=WatchWindow,DebugLogView
+
Index: cprs/branches/tmg-cprs/CPRS-Chart/CPRSChart_TLB.pas
===================================================================
--- cprs/branches/tmg-cprs/CPRS-Chart/CPRSChart_TLB.pas	(revision 660)
+++ cprs/branches/tmg-cprs/CPRS-Chart/CPRSChart_TLB.pas	(revision 667)
@@ -13,5 +13,5 @@
 
 // PASTLWTR : 1.2
-// File generated on 12/28/2009 9:26:13 PM from Type Library described below.
+// File generated on 1/12/2010 1:11:24 PM from Type Library described below.
 
 // ************************************************************************  //
Index: cprs/branches/tmg-cprs/CPRS-Chart/Encounter/fEncounterFrame.dfm
===================================================================
--- cprs/branches/tmg-cprs/CPRS-Chart/Encounter/fEncounterFrame.dfm	(revision 660)
+++ cprs/branches/tmg-cprs/CPRS-Chart/Encounter/fEncounterFrame.dfm	(revision 667)
@@ -1,5 +1,5 @@
 object frmEncounterFrame: TfrmEncounterFrame
-  Left = 290
-  Top = 108
+  Left = 272
+  Top = 219
   Width = 640
   Height = 451
@@ -59,4 +59,10 @@
     Height = 22
     Align = alTop
+    Font.Charset = DEFAULT_CHARSET
+    Font.Color = clBlack
+    Font.Height = -11
+    Font.Name = 'MS Sans Serif'
+    Font.Style = []
+    ParentFont = False
     TabOrder = 2
     OnChange = TabControlChange
Index: cprs/branches/tmg-cprs/CPRS-Chart/Options/fOptionsOther.dfm
===================================================================
--- cprs/branches/tmg-cprs/CPRS-Chart/Options/fOptionsOther.dfm	(revision 660)
+++ cprs/branches/tmg-cprs/CPRS-Chart/Options/fOptionsOther.dfm	(revision 667)
@@ -1,5 +1,5 @@
 object frmOptionsOther: TfrmOptionsOther
-  Left = 298
-  Top = 189
+  Left = 517
+  Top = 143
   Hint = 'Use system default settings'
   HelpContext = 9110
@@ -380,13 +380,11 @@
   object cbEnableTabColors: TCheckBox
     Left = 9
-    Top = 110
+    Top = 102
     Width = 169
     Height = 17
     Caption = 'Enable Custom Tab Colors'
     Checked = True
-    Enabled = False
     State = cbChecked
     TabOrder = 26
-    Visible = False
     OnClick = cbEnableTabColorsClick
   end
Index: cprs/branches/tmg-cprs/CPRS-Chart/Options/fOptionsOther.pas
===================================================================
--- cprs/branches/tmg-cprs/CPRS-Chart/Options/fOptionsOther.pas	(revision 660)
+++ cprs/branches/tmg-cprs/CPRS-Chart/Options/fOptionsOther.pas	(revision 667)
@@ -199,4 +199,5 @@
 procedure TfrmOptionsOther.FormCreate(Sender: TObject);
 begin
+  cbEnableTabColors.checked := uTabColorsEnabled;
   FStartDT  := 0;
   FStopDT   := 0;
@@ -351,9 +352,10 @@
 //kt added
 begin
-  uTabColorsEnabled := cbEnableTabColors.Checked;
-  cboTabColors.Enabled    := uTabColorsEnabled;
-  lblEditTabColor.Enabled := uTabColorsEnabled;
-  lblTabColors.Enabled    := uTabColorsEnabled;
-  pnlShowColor.Enabled    := uTabColorsEnabled;
+  uTabColorsEnabled := cbEnableTabColors.Checked;          //elh 01/12/10
+  frmFrame.tabPage.OwnerDraw := cbEnableTabColors.Checked; //elh 01/12/10
+  //cboTabColors.Enabled    := uTabColorsEnabled;
+  //lblEditTabColor.Enabled := uTabColorsEnabled;
+  //lblTabColors.Enabled    := uTabColorsEnabled;
+  //pnlShowColor.Enabled    := uTabColorsEnabled;
 end;
 
Index: cprs/branches/tmg-cprs/CPRS-Chart/fFrame.dfm
===================================================================
--- cprs/branches/tmg-cprs/CPRS-Chart/fFrame.dfm	(revision 660)
+++ cprs/branches/tmg-cprs/CPRS-Chart/fFrame.dfm	(revision 667)
@@ -1,5 +1,5 @@
 object frmFrame: TfrmFrame
-  Left = 280
-  Top = 183
+  Left = 164
+  Top = 193
   Width = 684
   Height = 487
@@ -626,5 +626,5 @@
       Align = alBottom
       Font.Charset = DEFAULT_CHARSET
-      Font.Color = clWindowText
+      Font.Color = clBlack
       Font.Height = -12
       Font.Name = 'MS Sans Serif'
Index: cprs/branches/tmg-cprs/CPRS-Chart/fFrame.pas
===================================================================
--- cprs/branches/tmg-cprs/CPRS-Chart/fFrame.pas	(revision 660)
+++ cprs/branches/tmg-cprs/CPRS-Chart/fFrame.pas	(revision 667)
@@ -976,5 +976,5 @@
   //kt replace later... CreateTab(CT_IMAGES,   'Images');   //kt  8/19/05
   LoadTabColors(CPRSChartINI,uTabColorsList);  //kt added 8/8/08
-
+  TabPage.OwnerDraw := uTabColorsEnabled;
   ShowHideChartTabMenus(mnuViewChart);
   //  We defer calling LoadUserPreferences to UMInitiate, so that the font sizing
@@ -3640,6 +3640,6 @@
 //  NF_FLAGGED_OI_EXP_INPT          : AlertType := 'Flagged Orderable Item (INPT)';  <-- original line.  //kt 7/17/2007
     NF_FLAGGED_OI_EXP_INPT          : AlertType := DKLangConstW('fFrame_Flagged_Orderable_Item_xINPTx'); //kt added 7/17/2007
-//  NF_FLAGGED_OI_EXP_OUTPT         : AlertType := 'Flagged Orderable Item (OUTPT)';  <-- original line.  //kt 7/17/2007
-    NF_FLAGGED_OI_EXP_OUTPT         : AlertType := DKLangConstW('fFrame_Flagged_Orderable_Item_xOUTPTx'); //kt added 7/17/2007
+//  NF_FLAGGED_OI_EXP_OUTPT         : AlertType := 'Flagged Orderable Item (OUTPT)';  <-- original line.  //kt2 7/17/2007
+    NF_FLAGGED_OI_EXP_OUTPT         : AlertType := DKLangConstW('fFrame_Flagged_Orderable_Item_xOUTPTx'); //kt2 added 7/17/2007
   else
     Exit;
@@ -4989,5 +4989,6 @@
     //this isn't working... This is not what I want.  Fix later...
     //For now, uTabColorsEnabled should always be TRUE.
-    Control.Canvas.FillRect(Rect);
+    //Control.Canvas.FillRect(Rect);   //elh   we will try to alter the OwnerDraw property here
+    //TabPage.OwnerDraw := uTabColorsEnabled;
   end;
 end;
@@ -5044,4 +5045,7 @@
 
   begin
+  //NOTE: Something in this function is causing MS Vista to not
+  //show tab text. I am commenting a few items to test at home on
+  //a 64-bit Vista machine.    //elh  01-11-10
     oRect    := Rect;
     inactiveColor := Darken(Color,75);  //75%
@@ -5054,14 +5058,14 @@
     end;
 
-    Control.Canvas.Font.Name := 'Tahoma';
+    Control.Canvas.Font.Name := 'Tahoma';  //Test4
     if Active then begin
-      Control.Canvas.Font.Style := Control.Canvas.Font.Style + [fsBold];
-      Control.Canvas.Font.Color := clBlack
+      Control.Canvas.Font.Style := Control.Canvas.Font.Style + [fsBold];  //Test3
+      Control.Canvas.Font.Color := clBlack    //Test1
     end else begin
-      Control.Canvas.Font.Style := Control.Canvas.Font.Style - [fsBold];
+      Control.Canvas.Font.Style := Control.Canvas.Font.Style - [fsBold];  //Test3
       //Control.Canvas.Font.Color := clBlack
-      Control.Canvas.Font.Color := clWhite;
-    end;
-
+      Control.Canvas.Font.Color := clWhite;   //Test1
+    end;
+    
     if (TabControl.TabPosition = tpLeft) or (TabControl.TabPosition = tpRight) then begin
 
@@ -5099,7 +5103,7 @@
 
     if Active then begin
-      Control.Canvas.Brush.Color := Color;
+      Control.Canvas.Brush.Color := Color;  //Test2
     end else begin
-      Control.Canvas.Brush.Color := inactiveColor;
+      Control.Canvas.Brush.Color := inactiveColor;  //Test2
     end;
     Control.Canvas.FillRect(Rect);
